var del     = require('del');
var gulp    = require('gulp');
var babel   = require('gulp-babel');
var sass    = require('gulp-ruby-sass');
var header  = require('gulp-header');
var rename  = require('gulp-rename');
var uglify  = require('gulp-uglify');
var umd     = require('gulp-wrap-umd');


// Variables
var distDir = './dist';
var pkg = require('./package.json');
var banner = ['/*!', pkg.name, pkg.version, '*/\n'].join(' ');
var umdOptions = {
  exports: 'Tooltip',
  namespace: 'Tooltip',
  deps: [{
    name: 'Drop',
    globalName: 'Drop',
    paramName: 'Drop',
    amdName: 'drop',
    cjsName: 'drop'
  },
  {
    name: 'Tether',
    globalName: 'Tether',
    paramName: 'Tether',
    amdName: 'tether',
    cjsName: 'tether'
  }]
};


// Clean
gulp.task('clean', function() {
  del.sync([distDir]);
});


// Javascript
gulp.task('js', ['clean'], function() {
  gulp.src('./src/js/**/*.js')
    .pipe(babel())
    .pipe(umd(umdOptions))
    .pipe(header(banner))

    // Original
    .pipe(gulp.dest(distDir + '/js'))

    // Minified
    .pipe(uglify())
    .pipe(rename({suffix: '.min'}))
    .pipe(gulp.dest(distDir + '/js'));
});


// CSS
gulp.task('css', function() {
  sass('./src/css', {
    loadPath: './bower_components',
    compass: true
  })
  .pipe(gulp.dest(distDir + '/css'));
});


// Documentation
// TODO: Redo documentation


// Watch
gulp.task('watch', ['js', 'css'], function() {
  gulp.watch('./src/js/**/*', ['js']);
  gulp.watch('./src/css/**/*', ['css']);
});


// Defaults
gulp.task('build', ['js', 'css'])
gulp.task('default', ['build'])

